[llvm-commits] [llvm] r141032 - /llvm/trunk/lib/Support/APFloat.cpp

Nick Lewycky nicholas at mxc.ca
Mon Oct 3 14:30:08 PDT 2011


Author: nicholas
Date: Mon Oct  3 16:30:08 2011
New Revision: 141032

URL: http://llvm.org/viewvc/llvm-project?rev=141032&view=rev
Log:
Fix typo in comments.

Modified:
    llvm/trunk/lib/Support/APFloat.cpp

Modified: llvm/trunk/lib/Support/APFloat.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Support/APFloat.cpp?rev=141032&r1=141031&r2=141032&view=diff
==============================================================================
--- llvm/trunk/lib/Support/APFloat.cpp (original)
+++ llvm/trunk/lib/Support/APFloat.cpp Mon Oct  3 16:30:08 2011
@@ -1192,7 +1192,7 @@
 
   if (omsb) {
     /* OMSB is numbered from 1.  We want to place it in the integer
-       bit numbered PRECISON if possible, with a compensating change in
+       bit numbered PRECISION if possible, with a compensating change in
        the exponent.  */
     exponentChange = omsb - semantics->precision;
 
@@ -2125,7 +2125,7 @@
   dstCount = partCount();
   precision = semantics->precision;
 
   /* We want the most significant PRECISON bits of SRC.  There may not
      be that many; extract what we can.  */
   if (precision <= omsb) {
     exponent = omsb - 1;
@@ -2125,7 +2125,7 @@
   precision = semantics->precision;
 
-  /* We want the most significant PRECISON bits of SRC.  There may not
+  /* We want the most significant PRECISION bits of SRC.  There may not
      be that many; extract what we can.  */
   if (precision <= omsb) {





More information about the llvm-commits mailing list